@@ -12,13 +12,13 @@ g.part1 = function(datadir=c(),outputdir=c(),f0=1,f1=c(),windowsizes = c(5,900,3
                    backup.cal.coef=c(),selectdaysfile=c(),dayborder=0,dynrange=c()) {
   if (length(datadir) == 0 | length(outputdir) == 0) {
     if (length(datadir) == 0) {
-      print("Variable datadir is not defined")
+      cat("\nVariable datadir is not defined")
     }
     if (length(outputdir) == 0) {
-      print("Variable outputdir is not specified")
+      cat("\nVariable outputdir is not specified")
     }
   }
-  if (f1 == 0) print("Warning: f1 = 0 is not a meaningful value")
+  if (f1 == 0) cat("\nWarning: f1 = 0 is not a meaningful value")
   filelist = isfilelist(datadir)
   #Extra code to handle raw accelerometer data in Raw data format:
   # list of all csv and bin files
@@ -33,7 +33,7 @@ g.part1 = function(datadir=c(),outputdir=c(),f0=1,f1=c(),windowsizes = c(5,900,3
   if (filelist == TRUE | useRDA == TRUE) {
     if (length(studyname) == 0) {
       studyname = "mystudy"
-      print("Error: studyname not specified in part1. Needed for analysing lists of files")
+      cat("\nError: studyname not specified in part1. Needed for analysing lists of files")
     } else {
       outputfolder = paste("/output_",studyname,sep="")
     }
@@ -100,7 +100,7 @@ g.part1 = function(datadir=c(),outputdir=c(),f0=1,f1=c(),windowsizes = c(5,900,3
   if (length(f0) ==  0) f0 = 1
   if (length(f1) ==  0) f1 = length(fnames)
   if (is.na(fnames[1]) == TRUE) {
-    print("Error: File path not clearly identified. Check path name")
+    cat("\nError: File path not clearly identified. Check path name")
   }
   if (f0 > length(fnames)) f0 = 1
   if (f1 > length(fnames)) f1 = length(fnames)
@@ -121,13 +121,13 @@ g.part1 = function(datadir=c(),outputdir=c(),f0=1,f1=c(),windowsizes = c(5,900,3
   #=================================================================
   # THE LOOP TO RUN THROUGH ALL BINARY FILES AND PROCES THEM
   if (length(fnames) == 0) {
-    print("no files to analyse")
+    cat("\nNo files to analyse")
   }
   filelocationkey = matrix("",length(fnames),3)
   fnames = sort(fnames)
   for (j in f0:f1) { #f0:f1 #j is file index (starting with f0 and ending with f1)
     if (print.filename == TRUE) {
-      print(paste("File name: ",fnames[j],sep=""))
+      cat(paste0("\nFile name: ",fnames[j]))
     }
     if (filelist == TRUE) {
       datafile = as.character(fnames[j])
@@ -176,7 +176,7 @@ g.part1 = function(datadir=c(),outputdir=c(),f0=1,f1=c(),windowsizes = c(5,900,3
     # Inspect file (and store output later on)
     options(warn=-1) #turn off warnings
     if (useRDA == FALSE) {
-      I = g.inspectfile(datafile)
+      I = g.inspectfile(datafile, desiredtz=desiredtz)
     } else {
       load(datafile) # to do: would be nice to only load the object I and not the entire datafile
       I$filename = fnames[j]
@@ -184,7 +184,7 @@ g.part1 = function(datadir=c(),outputdir=c(),f0=1,f1=c(),windowsizes = c(5,900,3
     options(warn=0) #turn on warnings
     if (overwrite == TRUE) skip = 0
     if (skip == 0) { #if skip = 1 then skip the analysis as you already processed this file
-      print(paste("P1 file",j,sep=""))
+      cat(paste0("\nP1 file",j))
       turn.do.cal.back.on = FALSE
       if (do.cal == TRUE & I$dformc == 3) { # do not do the auto-calibration for wav files (because already done in pre-processign)
         do.cal = FALSE
@@ -192,8 +192,9 @@ g.part1 = function(datadir=c(),outputdir=c(),f0=1,f1=c(),windowsizes = c(5,900,3
       }
       #--------------------------------------
       if (do.cal ==TRUE & useRDA == FALSE) {
-        print("---------------------------------------------")
-        print("investigate calibration of the sensors...")
+        # cat(paste0("\n",rep('-',options()$width),collapse=''))
+        cat("\n")
+        cat("\nInvestigate calibration of the sensors with function g.calibrate:\n")
         C = g.calibrate(datafile,use.temp=use.temp,spherecrit=spherecrit,
                         minloadcrit=minloadcrit,printsummary=printsummary,chunksize=chunksize,
                         windowsizes=windowsizes,selectdaysfile=selectdaysfile,dayborder=dayborder,
@@ -247,20 +248,16 @@ g.part1 = function(datadir=c(),outputdir=c(),f0=1,f1=c(),windowsizes = c(5,900,3
           C$scale = as.numeric(bcc.data[bcc.i[1],bcc.scalei])
           C$offset = as.numeric(bcc.data[bcc.i[1],bcc.offseti])
           C$tempoffset=  as.numeric(bcc.data[bcc.i[1],bcc.temp.offseti])
-          cat("\nNew offset correction:\n")
-          print(C$offset)
-          cat("\nNew scale correction:\n")
-          print(C$scale)
-          cat("\nNew tempoffset correction:\n")
-          print(C$tempoffset)
-          cat("\n----------------------------------------\n")
+          cat(paste0("\nNew offset correction ",c("x","y","z"),": ",C$offset))
+          cat(paste0("\nNew scale correction ",c("x","y","z"),": ",C$scale))
+          cat(paste0("\nNew tempoffset correction ",c("x","y","z"),": ",C$tempoffset))
         } else {
           cat("\nNo matching filename found in backup.cal.coef\n")
           cat(paste0("\nCheck that filename ",fnames[j]," exists in the csv-file\n"))
         }
       }
       #------------------------------------------------
-      print("get meta data...")
+      cat("\nExtract signal features (metrics) with the g.getmeta function:\n")
       M = g.getmeta(datafile,                  
                     do.bfen=do.bfen,
                     do.enmo=do.enmo,
@@ -282,7 +279,7 @@ g.part1 = function(datadir=c(),outputdir=c(),f0=1,f1=c(),windowsizes = c(5,900,3
                     outputfolder=outputfolder,
                     dayborder=dayborder,dynrange=dynrange)
       #------------------------------------------------
-      print("save .RData-file with: calibration report, file inspection report and all meta data...")
+      cat("\nSave .RData-file with: calibration report, file inspection report and all signal features...\n")
       # remove directory in filename if present
       filename = unlist(strsplit(fnames[j],"/"))
       if (length(filename) > 0) {
@@ -298,8 +295,6 @@ g.part1 = function(datadir=c(),outputdir=c(),f0=1,f1=c(),windowsizes = c(5,900,3
       SI = sessionInfo()
       save(SI,file=paste(path3,"/results/QC/sessioninfo_part1.RData",sep=""))
       rm(M); rm(I); rm(C)
-    } else {
-      #  print("file skipped because it was analysed before")
     }
     if(length(filelocationkey) > 0) {
       filelocationkey[,3] = datadir[j]
